import { format } from 'prettier/standalone';
import React, { useCallback, useMemo } from 'react';
import { PrismAsyncLight } from 'react-syntax-highlighter';
import { oneDark, oneLight } from 'react-syntax-highlighter/dist/esm/styles/prism';
import parserBabel from 'prettier/parser-babel';
import parserHtml from 'prettier/parser-html';
import parserPostcss from 'prettier/parser-postcss';
import parserMarkdown from 'prettier/parser-markdown';
import parserGraphql from 'prettier/parser-graphql';
import parserYaml from 'prettier/parser-yaml';
import styled from 'styled-components';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }
  strings.raw = raw;
  return strings;
}

var CodeHighlighterTheme;
(function (CodeHighlighterTheme) {
  CodeHighlighterTheme["Light"] = "light";
  CodeHighlighterTheme["Dark"] = "dark";
})(CodeHighlighterTheme || (CodeHighlighterTheme = {}));

var BABEL_LANGUAGES = ['tsx', 'jsx', 'typescript', 'javascript'];
var HTML_LANGUAGES = ['html'];
var CSS_LANGUAGES = ['css', 'less', 'scss'];
var MARKDOWN_LANGUAGES = ['markdown'];
var GRAPHQL_LANGUAGES = ['graphql'];
var YAML_LANGUAGES = ['yaml'];

// JavaScript/TypeScript
var getParserForLanguage = function getParserForLanguage(language) {
  var parser;
  var plugin;
  switch (true) {
    case BABEL_LANGUAGES.includes(language):
      parser = 'babel-ts';
      plugin = parserBabel;
      break;
    case HTML_LANGUAGES.includes(language):
      parser = 'html';
      plugin = parserHtml;
      break;
    case CSS_LANGUAGES.includes(language):
      parser = 'css';
      plugin = parserPostcss;
      break;
    case MARKDOWN_LANGUAGES.includes(language):
      parser = 'markdown';
      plugin = parserMarkdown;
      break;
    case GRAPHQL_LANGUAGES.includes(language):
      parser = 'graphql';
      plugin = parserGraphql;
      break;
    case YAML_LANGUAGES.includes(language):
      parser = 'yaml';
      plugin = parserYaml;
      break;
  }
  if (parser && plugin) {
    return {
      trailingComma: 'all',
      bracketSpacing: true,
      singleQuote: true,
      jsxSingleQuote: true,
      bracketSameLine: false,
      arrowParens: 'always',
      proseWrap: 'always',
      parser: parser,
      plugins: [plugin]
    };
  }
  return undefined;
};
var formatLanguage = function formatLanguage(language) {
  if (!language) {
    return '';
  }
  var formattedLanguage = {
    abap: 'ABAP',
    abnf: 'ABNF',
    actionscript: 'ActionScript',
    ada: 'Ada',
    agda: 'Agda',
    al: 'AL',
    antlr4: 'ANTLR4',
    apacheconf: 'ApacheConf',
    apex: 'Apex',
    apl: 'APL',
    applescript: 'AppleScript',
    aql: 'AQL',
    arduino: 'Arduino',
    arff: 'ARFF',
    asciidoc: 'AsciiDoc',
    asm6502: 'ASM6502',
    asmatmel: 'ASMatmel',
    aspnet: 'ASP.NET',
    autohotkey: 'AutoHotKey',
    autoit: 'AutoIt',
    avisynth: 'AviSynth',
    avroIdl: 'Avro IDL',
    bash: 'Bash',
    basic: 'Basic',
    batch: 'Batch',
    bbcode: 'BBCode',
    bicep: 'Bicep',
    birb: 'Birb',
    bison: 'Bison',
    bnf: 'BNF',
    brainfuck: 'Brainfuck',
    brightscript: 'BrightScript',
    bro: 'Bro',
    bsl: 'BSL',
    c: 'C',
    cfscript: 'CFScript',
    chaiscript: 'ChaiScript',
    cil: 'CIL',
    clike: 'C-like',
    clojure: 'Clojure',
    cmake: 'CMake',
    cobol: 'COBOL',
    coffeescript: 'CoffeeScript',
    concurnas: 'Concurnas',
    coq: 'Coq',
    cpp: 'C++',
    crystal: 'Crystal',
    csharp: 'C#',
    cshtml: 'CSHTML',
    csp: 'CSP',
    cssExtras: 'CSS Extras',
    css: 'CSS',
    csv: 'CSV',
    cypher: 'Cypher',
    d: 'D',
    dart: 'Dart',
    dataweave: 'DataWeave',
    dax: 'DAX',
    dhall: 'Dhall',
    diff: 'Diff',
    django: 'Django',
    dnsZoneFile: 'DNS Zone File',
    docker: 'Docker',
    dot: 'DOT',
    ebnf: 'EBNF',
    editorconfig: 'EditorConfig',
    eiffel: 'Eiffel',
    ejs: 'EJS',
    elixir: 'Elixir',
    elm: 'Elm',
    erb: 'ERB',
    erlang: 'Erlang',
    etlua: 'ETLua',
    excelFormula: 'Excel Formula',
    factor: 'Factor',
    falselang: 'Falselang',
    firestoreSecurityRules: 'Firestore Security Rules',
    flow: 'Flow',
    fortran: 'Fortran',
    fsharp: 'F#',
    ftl: 'FTL',
    gap: 'GAP',
    gcode: 'G-code',
    gdscript: 'GDScript',
    gedcom: 'GEDCOM',
    gherkin: 'Gherkin',
    git: 'Git',
    glsl: 'GLSL',
    gml: 'GML',
    gn: 'GN',
    goModule: 'Go Module',
    go: 'Go',
    graphql: 'GraphQL',
    groovy: 'Groovy',
    haml: 'Haml',
    handlebars: 'Handlebars',
    haskell: 'Haskell',
    haxe: 'Haxe',
    hcl: 'HCL',
    hlsl: 'HLSL',
    hoon: 'Hoon',
    hpkp: 'HPKP',
    hsts: 'HSTS',
    html: 'HTML',
    http: 'HTTP',
    ichigojam: 'IchigoJam',
    icon: 'Icon',
    icuMessageFormat: 'ICU Message Format',
    idris: 'Idris',
    iecst: 'IECST',
    ignore: 'Ignore',
    inform7: 'Inform7',
    ini: 'INI',
    io: 'Io',
    j: 'J',
    java: 'Java',
    javadoc: 'Javadoc',
    javadoclike: 'Javadoc-like',
    javascript: 'JavaScript',
    javastacktrace: 'Java Stack Trace',
    jexl: 'JEXL',
    jolie: 'Jolie',
    jq: 'jq',
    jsExtras: 'JS Extras',
    jsTemplates: 'JS Templates',
    jsdoc: 'JSDoc',
    json: 'JSON',
    json5: 'JSON5',
    jsonp: 'JSONP',
    jsstacktrace: 'JS Stack Trace',
    jsx: 'JSX',
    julia: 'Julia',
    keepalived: 'Keepalived',
    keyman: 'Keyman',
    kotlin: 'Kotlin',
    kumir: 'KuMir',
    kusto: 'Kusto',
    latex: 'LaTeX',
    latte: 'Latte',
    less: 'Less',
    lilypond: 'LilyPond',
    liquid: 'Liquid',
    lisp: 'Lisp',
    livescript: 'LiveScript',
    llvm: 'LLVM',
    log: 'Log',
    lolcode: 'LOLCODE',
    lua: 'Lua',
    magma: 'Magma',
    makefile: 'Makefile',
    markdown: 'Markdown',
    markupTemplating: 'Markup Templating',
    markup: 'Markup',
    matlab: 'MATLAB',
    maxscript: 'MAXScript',
    mel: 'MEL',
    mermaid: 'Mermaid',
    mizar: 'Mizar',
    mongodb: 'MongoDB',
    monkey: 'Monkey',
    moonscript: 'MoonScript',
    n1ql: 'N1QL',
    n4js: 'N4JS',
    nand2tetrisHdl: 'Nand2Tetris HDL',
    naniscript: 'NaninScript',
    nasm: 'NASM',
    neon: 'NEON',
    nevod: 'NevoD',
    nginx: 'Nginx',
    nim: 'Nim',
    nix: 'Nix',
    nsis: 'NSIS',
    objectivec: 'Objective-C',
    ocaml: 'OCaml',
    opencl: 'OpenCL',
    openqasm: 'OpenQasm',
    oz: 'Oz',
    parigp: 'PARI/GP',
    parser: 'Parser',
    pascal: 'Pascal',
    pascaligo: 'Pascaligo',
    pcaxis: 'PC-Axis',
    peoplecode: 'PeopleCode',
    perl: 'Perl',
    phpExtras: 'PHP Extras',
    php: 'PHP',
    phpdoc: 'PHPDoc',
    plsql: 'PL/SQL',
    powerquery: 'PowerQuery',
    powershell: 'PowerShell',
    processing: 'Processing',
    prolog: 'Prolog',
    promql: 'PromQL',
    properties: 'Properties',
    protobuf: 'Protocol Buffers',
    psl: 'PSL',
    pug: 'Pug',
    puppet: 'Puppet',
    pure: 'Pure',
    purebasic: 'PureBasic',
    purescript: 'PureScript',
    python: 'Python',
    q: 'Q',
    qml: 'QML',
    qore: 'Qore',
    qsharp: 'Q#',
    r: 'R',
    racket: 'Racket',
    reason: 'Reason',
    regex: 'RegExp',
    rego: 'Rego',
    renpy: 'RenPy',
    rest: 'reST',
    rip: 'Rip',
    roboconf: 'Roboconf',
    robotframework: 'Robot Framework',
    ruby: 'Ruby',
    rust: 'Rust',
    sas: 'SAS',
    sass: 'Sass',
    scala: 'Scala',
    scheme: 'Scheme',
    scss: 'SCSS',
    shellSession: 'Shell Session',
    smali: 'Smali',
    smalltalk: 'Smalltalk',
    smarty: 'Smarty',
    sml: 'SML',
    solidity: 'Solidity',
    solutionFile: 'Solution File',
    soy: 'Soy',
    sparql: 'SPARQL',
    splunkSpl: 'Splunk SPL',
    sqf: 'SQF',
    sql: 'SQL',
    squirrel: 'Squirrel',
    stan: 'Stan',
    stylus: 'Stylus',
    swift: 'Swift',
    systemd: 'systemd',
    t4Cs: 'T4CS',
    t4Templating: 'T4 Templating',
    t4Vb: 'T4VB',
    tap: 'TAP',
    tcl: 'Tcl',
    textile: 'Textile',
    toml: 'TOML',
    tremor: 'Tremor',
    tsx: 'TSX',
    tt2: 'TT2',
    turtle: 'Turtle',
    twig: 'Twig',
    typescript: 'TypeScript',
    typoscript: 'TypoScript',
    unrealscript: 'UnrealScript',
    uorazor: 'Uorazor',
    uri: 'URI',
    v: 'V',
    vala: 'Vala',
    vbnet: 'VB.NET',
    velocity: 'Velocity',
    verilog: 'Verilog',
    vhdl: 'VHDL',
    vim: 'Vim',
    visualBasic: 'Visual Basic',
    warpscript: 'WarpScript',
    wasm: 'WebAssembly',
    webIdl: 'WebIDL',
    wiki: 'Wiki',
    wolfram: 'Wolfram',
    wren: 'Wren',
    xeora: 'Xeora',
    xmlDoc: 'XML Doc',
    xojo: 'Xojo',
    xquery: 'XQuery',
    yaml: 'YAML',
    yang: 'YANG',
    zig: 'Zig'
  };
  return formattedLanguage[language] || language;
};

var _templateObject, _templateObject2, _templateObject3;
var StyledCodeHighlighter = /*#__PURE__*/styled.div(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    margin: 4px 0;\n    background-color: ", ";\n    border-radius: 8px;\n    padding-bottom: 6px;\n\n    pre {\n        margin: 0 !important;\n        overflow: auto;\n        padding: 1em;\n        line-height: 1.5;\n\n        // Styles for custom scrollbar\n\n        &::-webkit-scrollbar {\n            height: 5px;\n        }\n\n        &::-webkit-scrollbar-track {\n            background-color: transparent;\n        }\n\n        &::-webkit-scrollbar-button {\n            background-color: transparent;\n            height: 2px;\n        }\n\n        &::-webkit-scrollbar-thumb {\n\n            background-color: rgba(", ",\n            1);\n            border-radius: 20px;\n        }\n\n        // Scrollbar styles for Firefox. The above styles are not supported in Firefox, these styles are\n        // only supported in Firefox:\n\n        * {\n            scrollbar-color: rgba(", ",\n            1);\n        ) transparent;\n            scrollbar-width: thin;\n        }\n    }\n"])), function (_ref) {
  var codeTheme = _ref.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#282c34' : '#fafafa';
}, function (_ref2) {
  var codeTheme = _ref2.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '229, 229, 229' : '153, 153, 153';
}, function (_ref3) {
  var codeTheme = _ref3.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '229, 229, 229' : '153, 153, 153';
});
var StyledCodeHighlighterHeader = /*#__PURE__*/styled.div(_templateObject2 || (_templateObject2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    display: flex;\n    align-items: center;\n    justify-content: space-between;\n    border-bottom: 1px solid\n        ", ";\n    padding: 4px 12px;\n"])), function (_ref4) {
  var codeTheme = _ref4.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});
var StyledCodeHighlighterFileName = /*#__PURE__*/styled.span(_templateObject3 || (_templateObject3 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    color: ", ";\n"])), function (_ref5) {
  var codeTheme = _ref5.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});

var _templateObject$1, _templateObject2$1, _templateObject3$1;
var StyledCopyToClipboard = /*#__PURE__*/styled.div(_templateObject$1 || (_templateObject$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    display: flex;\n    align-items: center;\n"])));
var StyledCopyToClipboardIcon = /*#__PURE__*/styled.i(_templateObject2$1 || (_templateObject2$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    color: ", ";\n"])), function (_ref) {
  var codeTheme = _ref.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});
var StyledCopyToClipboardText = /*#__PURE__*/styled.span(_templateObject3$1 || (_templateObject3$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n    color: ", ";\n    font-size: small;\n    margin-left: 4px;\n"])), function (_ref2) {
  var codeTheme = _ref2.codeTheme;
  return codeTheme === CodeHighlighterTheme.Dark ? '#e5e5e5' : '#999999';
});

var CopyToClipboard = function CopyToClipboard(_ref) {
  var copyButtonText = _ref.copyButtonText,
    text = _ref.text,
    theme = _ref.theme;
  var handleClick = function handleClick() {
    void navigator.clipboard.writeText(text);
  };
  return React.createElement(StyledCopyToClipboard, {
    onClick: handleClick
  }, React.createElement(StyledCopyToClipboardIcon, {
    className: "fa-regular fa-clipboard",
    codeTheme: theme
  }), copyButtonText && React.createElement(StyledCopyToClipboardText, {
    codeTheme: theme
  }, copyButtonText));
};
CopyToClipboard.displayName = 'CopyToClipboard';

var CodeHighlighter = function CodeHighlighter(_ref) {
  var _ref$theme = _ref.theme,
    theme = _ref$theme === void 0 ? CodeHighlighterTheme.Dark : _ref$theme,
    code = _ref.code,
    copyButtonText = _ref.copyButtonText,
    language = _ref.language,
    highlightedLines = _ref.highlightedLines,
    _ref$shouldFormatCode = _ref.shouldFormatCode,
    shouldFormatCode = _ref$shouldFormatCode === void 0 ? false : _ref$shouldFormatCode,
    _ref$shouldShowLineNu = _ref.shouldShowLineNumbers,
    shouldShowLineNumbers = _ref$shouldShowLineNu === void 0 ? false : _ref$shouldShowLineNu;
  // function to style highlighted code
  var lineWrapper = useCallback(function (lineNumber) {
    var style = {
      backgroundColor: 'none',
      display: 'block',
      borderRadius: '2px'
    };
    if (highlightedLines != null && highlightedLines.added && highlightedLines.added.includes(lineNumber)) {
      style = _extends({}, style, {
        backgroundColor: '#2EF29930'
      });
    } else if (highlightedLines != null && highlightedLines.removed && highlightedLines.removed.includes(lineNumber)) {
      style = _extends({}, style, {
        backgroundColor: '#F22E5B30'
      });
    } else if (highlightedLines != null && highlightedLines.marked && highlightedLines.marked.includes(lineNumber)) {
      style = _extends({}, style, {
        backgroundColor: '#cccccc40'
      });
    }
    return {
      style: style
    };
  }, [highlightedLines]);
  var formattedCode = useMemo(function () {
    if (language) {
      var config = getParserForLanguage(language);
      if (shouldFormatCode && config) {
        return format(code, config);
      }
      return code;
    }
    return code;
  }, [code, language, shouldFormatCode]);
  return useMemo(function () {
    return React.createElement(StyledCodeHighlighter, {
      codeTheme: theme
    }, React.createElement(StyledCodeHighlighterHeader, {
      codeTheme: theme
    }, React.createElement(StyledCodeHighlighterFileName, {
      codeTheme: theme
    }, formatLanguage(language)), React.createElement(CopyToClipboard, {
      text: code,
      theme: theme,
      copyButtonText: copyButtonText
    })), React.createElement(PrismAsyncLight, {
      language: language != null ? language : '',
      showLineNumbers: shouldShowLineNumbers,
      style: theme === CodeHighlighterTheme.Dark ? oneDark : oneLight,
      wrapLines: true,
      lineProps: lineWrapper
    }, formattedCode));
  }, [theme, language, code, copyButtonText, shouldShowLineNumbers, lineWrapper, formattedCode]);
};
CodeHighlighter.displayName = 'CodeHighlighter';

export { CodeHighlighter, CodeHighlighterTheme };
//# sourceMappingURL=code-highlighter-react.esm.js.map
